# CBpanel "SearchBox" plugin

name = "SearchBox"
description = """Provide a smart box to search on the internet."""

import CBpanel, gtk, gobject, os, pango

class SearchWindow(CBpanel.panelMenuWindow):
    def __init__(self, panel, plugin):
        CBpanel.panelMenuWindow.__init__(self, "Web search", "type your search below", \
                                         panel.get_image_from_icon_name("web-browser", 24), panel, 3, \
                                         gtk.WINDOW_TOPLEVEL)
        self.plugin = plugin

        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_NORMAL)

        box = gtk.HBox(False, 2)
        box.set_border_width(0)
        self.append(box)
        self.entry = gtk.Entry()
        self.entry.x_done = False
        self.entry.set_name("TextBox")
        self.entry.set_width_chars(25)
        self.entry.connect("button-press-event", self.manage_click)
        self.entry.connect("activate", self.go)
        box.pack_start(self.entry, True)
        btn = gtk.Button()
        #~ btn.set_name("EdgeButton")
        btn.connect("clicked", self.onClicked)
        btn.set_label("Search")
        #~ btn.set_relief(gtk.RELIEF_NONE)
        btn.set_border_width(0)
        btn.set_focus_on_click(False)
        #~ btn.set_property('can-focus', False)
        box.pack_end(btn, False)
        box.show_all()

    def onClicked(self, btn):
        self.executeSearch()

    def go(self, entry):
        self.executeSearch()

    def executeSearch(self):
        url = "'" + self.plugin.engineurl % self.entry.get_text() + "'"
        cmd = self.plugin.browser % url
        self.plugin.logDEBUG(("Launching \"%s\"") % (cmd))
        os.spawnl(os.P_NOWAIT, "/bin/sh", "/bin/sh", "-c", cmd)
        self.entry.x_done = True
        self.entry.set_text("")
        self.toggle()

    def manage_click(self, entry, event):
        self.fixFocus()

    def fixFocus(self):
        self.entry.grab_focus()
        self.panel.set_focus(self.entry)
        if self.entry.x_done:
            self.entry.set_text("")
            self.entry.x_done = False

    def toggle(self, widget = 0):
        CBpanel.PopupWindow.toggle(self, widget)
        self.fixFocus()

class Plugin(CBpanel.Plugin):
    def __init__(self, panel, settings):
        CBpanel.Plugin.__init__(self, panel, settings)
        self.set_border_width(0)

        self.browser = "firefox %s"
        self.engineurl = "http://www.google.com/search?q=%s"
        if settings.has_key('browser'):
            self.browser = settings['browser']
            if self.browser.find("%s") < 0:
                self.browser += " %s"
        if settings.has_key('engineurl'):
            self.engineurl = settings['engineurl']
        self.swindow = SearchWindow(panel, self)
        self.logDEBUG("Browser set to '%s'" % (self.browser))

        btn = gtk.ToggleButton()
        btn.set_name("EdgeButton")
        btn.connect("toggled", self.swindow.toggle)
        btn.connect("enter-notify-event", self.swindow.toggleConditional)
        btn.set_relief(gtk.RELIEF_NONE)
        btn.set_border_width(0)
        btn.set_focus_on_click(False)
        btn.set_property('can-focus', False)

        #~ CBpanel.tooltips.set_tip(btn, "Search the world wide web")
        self.add(btn)

        aicon = "web-browser"

        if settings.has_key('icon') and settings['icon']!=None:
            aicon = settings['icon']

        if len(aicon)>0:
            img = self.panel.get_image_from_icon_name(aicon)
            btn.add(img)

        self.show_all()
